@@ -1,5 +1,5 @@
 '''
-一个优雅、简洁的 mysql ORM
+mysql ORM
 作者: jutooy
 邮箱: jutooy@qq.com
 基于 pymysql 开发
